// GoogleClientBeanSLL.java
// Stateless Session bean

package org.objectweb.wssample.beans.ws;

import java.rmi.RemoteException;
import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;
import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.RemoveException;
import javax.ejb.EJBObject;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.sql.DataSource;

import org.objectweb.jonas.common.Log;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.BasicLevel;

import org.objectweb.wssample.gen.google.GoogleSearchResult;
import org.objectweb.wssample.gen.google.GoogleSearchService;
import org.objectweb.wssample.gen.google.GoogleSearchPort;

import javax.xml.rpc.ServiceException;

/**
 *
 */
public class GoogleClientBeanSLL implements SessionBean {

    static private Logger logger = null;
    SessionContext ejbContext;

    // ------------------------------------------------------------------
    // SessionBean implementation
    // ------------------------------------------------------------------


    public void setSessionContext(SessionContext ctx) {
        if (logger == null) {
            logger = Log.getLogger("org.objectweb.jonas_tests");
        }
        logger.log(BasicLevel.DEBUG, "");
        ejbContext = ctx;
    }
        

    public void ejbRemove() {
        logger.log(BasicLevel.DEBUG, "");
    }
        

    public void ejbCreate() throws CreateException {
        logger.log(BasicLevel.DEBUG, "");
    }

    public void ejbPassivate() {
        logger.log(BasicLevel.DEBUG, "");
    }

    public void ejbActivate() {
        logger.log(BasicLevel.DEBUG, "");
    }
    
    // ------------------------------------------------------------------
    // GoogleClientBean implementation
    // ------------------------------------------------------------------


    public GoogleSearchResult executeQuery(java.lang.String query) {

        logger.log(BasicLevel.INFO, "Executing Google Query '" + query + "'");

        try {
            
            // Get the InitialContext where retrieve Service
            Context ctx = new InitialContext();
            
            // Lookup the service
            GoogleSearchService google = 
                (GoogleSearchService) ctx.lookup("java:comp/env/service/google");
            
            // get Google Port
            GoogleSearchPort search = google.getGoogleSearchPort();
            
            // get Google Key
            String key = (String) ctx.lookup("java:comp/env/googleKey");
            
            // Execute the query
            return search.doGoogleSearch(  key, 
                                           query,
                                           0,     // first index
                                           10,    // maxresult
                                           false, //filter
                                           null, //restrict
                                           false, // safesearch
                                           null, //lr
                                           null, //ie
                                           null  //oe
                                           );
        } catch (NamingException ne) {
            return null;
        } catch (RemoteException re) {
            return null;
        } catch (ServiceException se) {
            return null;
        }
    }
}

