package xdoclet;

import javax.ejb.EntityContext;
import java.util.Date;
import javax.naming.InitialContext;
import javax.naming.NamingException;
/**
 * PhoneBean is an entity bean with "container managed persistence version 2".
 * The state of an instance is stored into a relational database. 
 *
 * @ejb.bean
 *      name="PhoneBean" 
 *      description="Deployment descriptor for the PhoneBean bean with CMP2 JOnAS example"
 *      type="CMP"
 *      view-type="local"
 *      primkey-field="id"
 *      cmp-version="2.x"
 * @ejb.home
 *	local-class="xdoclet.PhoneHomeLocal"
 * @ejb.interface
 *      local-class="xdoclet.PhoneLocal"
 * @ejb:pk 
 *      class="java.lang.Integer"
 * @jonas.bean
 *      ejb-name="PhoneBean"
 *      jndi-name="PhoneBeanHome"
 *
 * @jonas.jdbc-mapping
 *      jndi-name="jdbc_1"
 *      jdbc-table-name  = "MyPhone"
 *      automatic-pk="true"
 *
 * @ejb:finder
 *	signature= "java.util.Collection findAllPhones()"
 *	query ="SELECT OBJECT(o) FROM PhoneBean o"
 *
 * @jonas.session-timeout
 *       session-timeout="60"
 * @ejb:transaction
 	type="Required"
 */

public abstract class PhoneBean implements javax.ejb.EntityBean {
	
    /**
     * EJBCREATE
     * @return pk primary key set to null
     *
     * @ejb.create-method
     */
    public Object ejbCreate( String number, byte type) throws javax.ejb.CreateException {
	setNumber(number);
	setType(type);
	return null;
    }

    public void ejbPostCreate(String number, byte type) {
	System.out.println("PhoneBean ejbPostCreate number= "+number+"ID = "+this.getId());
    }

    // persistent fields
    /**
     * @ejb.persistent-field
     * @ejb.interface-method
     */
    public abstract Integer getId();
    /**
     * @ejb.persistent-field
     * @ejb.interface-method
     */
    public abstract void setId(Integer id);
    /**
     * @ejb.persistent-field
     * @ejb.interface-method
     */
    public abstract String getNumber();
    /**
     * @ejb.persistent-field
     * @ejb.interface-method
     */
    public abstract void setNumber(String number);
    /**
     * @ejb.persistent-field
     * @ejb.interface-method
     */
    public abstract byte getType();
   /**
     * @ejb.persistent-field
     * @ejb.interface-method
    */
    public abstract void setType(byte type);

    // standard call back methods
    
    public void setEntityContext(EntityContext ec){}
    public void unsetEntityContext(){}
    public void ejbLoad(){}
    public void ejbStore(){}
    public void ejbActivate(){}
    public void ejbPassivate(){}
    public void ejbRemove() throws javax.ejb.RemoveException{}

}
